===============
Version History
===============

.. automodule:: petbox.dca
   :noindex:


1.0.5
-----

* New functions
    * Bourdet algorithm

* Other Changes
    * Update docstrings
    * Add bourdet data derivatives to detailed use examples


1.0.4
-----

* Fix typos in docs


1.0.3
-----

* Add documentation
* Genericize numerical integration
* Various refactoring


0.0.1 - 1.0.2
-------------

* Internal releases
